Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(58)

Unified Diff: chrome/app/chrome_main.cc

Issue 5491001: Mac: Sandbox GPU process. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: make tests work for now Created 10 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | chrome/browser/gpu.sb » ('j') | chrome/common/child_process.cc » ('J')
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/app/chrome_main.cc
diff --git a/chrome/app/chrome_main.cc b/chrome/app/chrome_main.cc
index 55c009de9ab2943aa45ab291f8bedbb554ed4244..b27e144cce037cfdad6c2ad3ac43ba0eaa841275 100644
--- a/chrome/app/chrome_main.cc
+++ b/chrome/app/chrome_main.cc
@@ -874,10 +874,12 @@ int ChromeMain(int argc, char** argv) {
#if defined(OS_MACOSX)
// On OS X the renderer sandbox needs to be initialized later in the startup
// sequence in RendererMainPlatformDelegate::EnableSandbox().
// Same goes for NaClLoader, in NaClMainPlatformDelegate::EnableSandbox().
if (process_type != switches::kRendererProcess &&
process_type != switches::kExtensionProcess &&
- process_type != switches::kNaClLoaderProcess) {
+ process_type != switches::kNaClLoaderProcess &&
+ process_type != switches::kGpuProcess) {
bool sandbox_initialized_ok =
sandbox_wrapper.InitializeSandbox(parsed_command_line, process_type);
// Die if the sandbox can't be enabled.
@@ -874,10 +874,12 @@ int ChromeMain(int argc, char** argv) {
// On OS X the renderer sandbox needs to be initialized later in the startup
// sequence in RendererMainPlatformDelegate::EnableSandbox().
- // Same goes for NaClLoader, in NaClMainPlatformDelegate::EnableSandbox().
+ // Same goes for NaClLoader, in NaClMainPlatformDelegate::EnableSandbox(),
+ // and the GPU process, in GpuMain().
if (process_type != switches::kRendererProcess &&
process_type != switches::kExtensionProcess &&
« no previous file with comments | « no previous file | chrome/browser/gpu.sb » ('j') | chrome/common/child_process.cc » ('J')

Powered by Google App Engine
This is Rietveld 408576698